==> component-mybatis-spring-boot-starter-2.1.2-20210706.104104-18-sources.jar: com/bxm/component/mybatis/dbshunt/strategy/handle/AbstractTableHandler.java <==
package com.bxm.component.mybatis.dbshunt.strategy.handle;

import com.bxm.component.mybatis.dbshunt.entity.ShuntTableLog;
import com.bxm.component.mybatis.dbshunt.enums.DBShuntTypeEnum;
import com.bxm.component.mybatis.dbshunt.mapper.DBShuntMapper;
import com.bxm.component.mybatis.dbshunt.param.ShuntParam;
import com.bxm.component.mybatis.dbshunt.strategy.TableHandler;
import com.bxm.newidea.component.tools.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;

import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * @author lowi
 * @date 2021/6/28 18:04
 */
@Slf4j
public abstract class AbstractTableHandler implements TableHandler {


    static final String TABLE_LOG_NAME = "t_db_shunt_table_log";


    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Autowired
    DBShuntMapper dbShuntMapper;


    /**
     * 初始化分表记录表信息
     *
     * @param dataName 库名
     */
    void initShuntTableData(String dataName) {

        int existTable = dbShuntMapper.isExistTable(dataName, TABLE_LOG_NAME);

        if (existTable > 0) {
            return;
        }

        dbShuntMapper.initShuntTableData();
    }

    /**
     * 获取入参传值的表是否做了分表
     *
     * @param dataName  库名
     * @param tableName 表名
     * @return 查询出来匹配的表
     */
    List<String> getTableNameList(String dataName, String tableName) {

        return dbShuntMapper.isExistLikeTable(dataName, tableName);
    }

    void initNewNameTable(String newTableName, ShuntParam shuntParam) {

        int existTable = dbShuntMapper.isExistTable(shuntParam.getDataName(), newTableName);

        //如果新表 是存在的 则不用建新表
        if (existTable > 0) {
            return;
        }

        List<Map<String, Object>> tableFieldInfo = dbShuntMapper.getTableFieldInfo(shuntParam.getDataName(), shuntParam.getTableName());

        StringBuilder createTable = new StringBuilder();
        createTable.append("CREATE TABLE ").append(newTableName).append("(");
        String primaryKey = null;
        for (Map<String, Object> map : tableFieldInfo) {
            createTable.append(" `").append(map.get("COlUMN_NAME")).append("` ");
            createTable.append(" ").append(map.get("COLUMN_TYPE")).append(" ");

            if (Objects.equals(map.get("IS_NULLABLE"), "YES")) {
                createTable.append(" DEFAULT NULL ");
            } else {
                createTable.append(" NOT NULL ");
            }

            if (StringUtils.isNotBlank(map.get("COLUMN_KEY").toString()) && "PRI".equals(map.get("COLUMN_KEY").toString())) {
                primaryKey = map.get("COlUMN_NAME").toString();
            }
            createTable.append(" COMMENT '").append(map.get("COLUMN_COMMENT")).append("', ");
        }

        if (primaryKey != null) {
            createTable.append(" PRIMARY KEY (`").append(primaryKey).append("`)");
            createTable.append(" )");
        } else {
            createTable.append(" )");
        }

        if (!tableFieldInfo.isEmpty()) {
            jdbcTemplate.update(createTable.toString());
        }
    }

    ShuntTableLog getLastLogByTableNameAndType(String tableName, DBShuntTypeEnum dbShuntTypeEnum) {
        return dbShuntMapper.getLastLogByTableNameAndType(TABLE_LOG_NAME, tableName, dbShuntTypeEnum.getType());
    }
}

==> component-mybatis-spring-boot-starter-2.1.7.1-sources.jar: com/bxm/component/mybatis/dbshunt/strategy/handle/AbstractTableHandler.java <==
package com.bxm.component.mybatis.dbshunt.strategy.handle;

import com.bxm.component.mybatis.dbshunt.entity.ShuntTableLog;
import com.bxm.component.mybatis.dbshunt.enums.DBShuntTypeEnum;
import com.bxm.component.mybatis.dbshunt.mapper.DBShuntMapper;
import com.bxm.component.mybatis.dbshunt.param.ShuntParam;
import com.bxm.component.mybatis.dbshunt.strategy.TableHandler;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;

import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * @author lowi
 * @date 2021/6/28 18:04
 */
@Slf4j
public abstract class AbstractTableHandler implements TableHandler {


    static final String TABLE_LOG_NAME = "t_db_shunt_table_log";


    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Autowired
    DBShuntMapper dbShuntMapper;


    /**
     * 初始化分表记录表信息
     *
     * @param dataName 库名
     */
    void initShuntTableData(String dataName) {

        int existTable = dbShuntMapper.isExistTable(dataName, TABLE_LOG_NAME);

        if (existTable > 0) {
            return;
        }

        dbShuntMapper.initShuntTableData();
    }

    /**
     * 获取入参传值的表是否做了分表
     *
     * @param dataName  库名
     * @param tableName 表名
     * @return 查询出来匹配的表
     */
    List<String> getTableNameList(String dataName, String tableName) {

        return dbShuntMapper.isExistLikeTable(dataName, tableName);
    }

    void initNewNameTable(String newTableName, ShuntParam shuntParam) {

        int existTable = dbShuntMapper.isExistTable(shuntParam.getDataName(), newTableName);

        //如果新表 是存在的 则不用建新表
        if (existTable > 0) {
            return;
        }

        List<Map<String, Object>> tableFieldInfo = dbShuntMapper.getTableFieldInfo(shuntParam.getDataName(), shuntParam.getTableName());

        StringBuilder createTable = new StringBuilder();
        createTable.append("CREATE TABLE ").append(newTableName).append("(");
        String primaryKey = null;
        for (Map<String, Object> map : tableFieldInfo) {
            createTable.append(" `").append(map.get("COlUMN_NAME")).append("` ");
            createTable.append(" ").append(map.get("COLUMN_TYPE")).append(" ");

            if (Objects.nonNull(map.get("CHARACTER_SET_NAME")) && "utf8mb4".equals(map.get("CHARACTER_SET_NAME").toString().toLowerCase())) {
                createTable.append(" CHARACTER SET utf8mb4 ");
            }

            if (Objects.equals(map.get("IS_NULLABLE"), "YES")) {
                createTable.append(" DEFAULT NULL ");
            } else {
                createTable.append(" NOT NULL ");
            }

            if (Objects.nonNull(map.get("COLUMN_KEY").toString()) && "PRI".equals(map.get("COLUMN_KEY").toString())) {
                primaryKey = map.get("COlUMN_NAME").toString();
            }
            createTable.append(" COMMENT '").append(map.get("COLUMN_COMMENT")).append("', ");
        }

        if (primaryKey != null) {
            createTable.append(" PRIMARY KEY (`").append(primaryKey).append("`)");
            createTable.append(" )");
        } else {
            createTable.append(" )");
        }

        if (!tableFieldInfo.isEmpty()) {
            jdbcTemplate.update(createTable.toString());
        }
    }

    ShuntTableLog getLastLogByTableNameAndType(String tableName, DBShuntTypeEnum dbShuntTypeEnum) {
        return dbShuntMapper.getLastLogByTableNameAndType(TABLE_LOG_NAME, tableName, dbShuntTypeEnum.getType());
    }
}
